@@ -8,8 +8,7 @@ zenodo_token <- "<token>"
 zenodo_logger <- "DEBUG"
 ZENODO <- try(ZenodoManager$new(url = zenodo_url, token = zenodo_token, logger = zenodo_logger))
 
-deps <- ZENODO$getDepositions(size = 1)
-if(is(deps[[1]], "ZenodoRecord")){
+if(is(ZENODO, "ZenodoManager")){
   cat(sprintf("Zenodo sandbox '%s' configured with token. Running integration tests...\n", zenodo_url))
   test_check("zen4R")
 }else{
